Vectors
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   vectors.rst
   accessing_elements.rst
   copying_vectors.rst
   for_loops.rst
   vector_size.rst
   vector_functions.rst
   random_numbers.rst
   statistics.rst
   vector_of_random_numbers.rst
   counting.rst
   checking_the_other_values.rst
   histogram.rst
   single-pass_solution.rst
   random_seeds.rst
   glossary.rst
   Exercises.rst
   mixedUpCode.rst
   activeCode.rst